@@ -1,16 +1,17 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 #
 #
 # A Net::DRI example
 
 use strict;
+use warnings;
 
 use Net::DRI;
 
 my $dri=Net::DRI->new(10);
 my $rc;
 
-eval {
+my $ok=eval {
 ############################################################################################################
 
 $dri->add_registry('VNDS',{});
@@ -38,6 +39,7 @@ $dri->add_registry('EURid',{});
 $rc=$dri->target('EURid')->add_current_profile('profile1','whois');
 die($rc) unless $rc->is_success();
 display('europa.eu',$dri);
+display('eurid.eu',$dri);
 
 $dri->add_registry('BIZ',{});
 $rc=$dri->target('BIZ')->add_current_profile('profile1','whois');
@@ -89,19 +91,24 @@ $rc=$dri->target('US')->add_current_profile('profile1','whois');
 die($rc) unless $rc->is_success();
 display('disney.us',$dri);
 
+$dri->add_registry('PT',{});
+$rc=$dri->target('PT')->add_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('lisboa.pt',$dri);
 
 $dri->end();
 };
 
-if ($@)
+if (! $ok)
 { 
+ my $err=$@;
  print "\n\nAn EXCEPTION happened !\n";
- if (ref($@))
+ if (ref $err)
  {
-  $@->print();
+  $err->print();
  } else
  {
-  print($@);
+  print $err;
  }
 } else
 {
@@ -118,7 +125,7 @@ sub display
  my $rc=$dri->domain_info($dom);
  print 'IS_SUCCESS: '.$dri->result_is_success().' [CODE: '.$dri->result_code().' / '.$dri->result_native_code()."]\n";
  my $e=$dri->get_info('exist');
- print 'EXIST: '.$e."\n";
+ print 'EXIST: '.$e."\n" if defined $e;
  if ($e)
  {
   foreach my $k (qw/clName clID clWebsite clWhois upName upID crName crID crDate upDate exDate wuDate/)
