@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .INFO policies
 ##
 ## Copyright (c) 2006-2009 Rony Meyer <perl@spot-light.ch>. All rights reserved.
-##           (c) 2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+##           (c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,9 +11,6 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::DRD::INFO;
@@ -25,8 +22,6 @@ use base qw/Net::DRI::DRD/;
 
 use DateTime::Duration;
 
-our $VERSION=do { my @r=(q$Revision: 1.7 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -56,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2006-2009 Rony Meyer <perl@spot-light.ch>.
-          (c) 2010 Patrick Mevzek <netdri@dotandco.com>.
+          (c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -77,7 +72,6 @@ sub new
  $self->{info}->{host_as_attr}=0;
  $self->{info}->{contact_i18n}=2; ## INT only
  $self->{info}->{check_limit}=38; ## Upper limit computed to that XML stream length is < 4096 bytes
- bless($self,$class);
  return $self;
 }
 
