@@ -1,7 +1,7 @@
-## Domain Registry Interface, AFNIC (.FR/.RE) EPP extensions
+## Domain Registry Interface, AFNIC (.FR/.RE/.TF/.WF/.PM/.YT) EPP extensions
 ## From http://www.afnic.fr/medias/documents/afnic-guide-integration-technique.pdf (v1.55 2011-03-03)
 ##
-## Copyright (c) 2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2012 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -26,7 +26,7 @@ use Net::DRI::Protocol::EPP::Extensions::AFNIC::Status;
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::AFNIC - AFNIC (.FR/.RE) EPP extensions for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::AFNIC - AFNIC (.FR/.RE/.TF/.WF/.PM/.YT) EPP extensions for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2012 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,10 +67,11 @@ See the LICENSE file that comes with this distribution for more details.
 sub setup
 {
  my ($self,$rp)=@_;
- $self->ns({frnic=>['http://www.afnic.fr/xml/epp/frnic-1.1','frnic-1.1.xsd']});
+ $self->ns({frnic=>['http://www.afnic.fr/xml/epp/frnic-1.2','frnic-1.2.xsd']});
  $self->capabilities('domain_update','registrant',undef); ## a trade is required
  $self->capabilities('contact_update','status',undef); ## No changes in status possible for .FR contacts
  $self->capabilities('contact_update','disclose',['add','del']);
+ $self->capabilities('contact_update','qualification',['add','del']);
  $self->capabilities('domain_update','secdns',['add','del']); ## no chg allowed for maxSigLife
  $self->capabilities('domain_update','secdns_urgent',undef); ## no urgent attribute allowed
  $self->factories('contact',sub { return Net::DRI::Data::Contact::AFNIC->new(); });
