@@ -1,6 +1,6 @@
 ## Domain Registry Interface, VeriSign EPP WhoWas Extension
 ##
-## Copyright (c) 2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2010,2012 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -116,7 +116,7 @@ Net::DRI::Protocol::EPP::Extensions::VeriSign::WhoWas - VeriSign EPP WhoWas Exte
 =head1 SYNOPSIS
 
         $dri=Net::DRI->new();
-        $dri->add_registry('VNDS',{clid=>'XXXXXX');
+        $dri->add_registry('VNDS',{client_id=>'XXXXXX');
 
         ...
 
@@ -146,7 +146,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2010 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2010,2012 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
