@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Dummy transport for tests & debug
 ##
-## Copyright (c) 2005,2007,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007,2009,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,20 +10,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 #########################################################################################
 
 package Net::DRI::Transport::Dummy;
 
-use base qw(Net::DRI::Transport);
 use strict;
+use warnings;
+
+use base qw(Net::DRI::Transport);
 
 use Net::DRI::Data::Raw;
 
-our $VERSION=do { my @r=(q$Revision: 1.11 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -52,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2007,2009,2011 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,12 +62,10 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
+
 sub new
 {
- my $class=shift;
- my $ctx=shift;
- my $rh=shift;
-
+ my ($class,$ctx,$rh)=@_;
  my $self=$class->SUPER::new($ctx,$rh); ## We are now officially a Net::DRI::Transport instance
  $self->has_state(0);
  $self->is_sync(1);
@@ -80,12 +75,9 @@ sub new
  $self->{f_send}=(exists($rh->{f_send}))? $rh->{f_send} : \&_print;
  $self->{f_recv}=(exists($rh->{f_recv}))? $rh->{f_recv} : \&_got_ok;
 
- bless($self,$class); ## rebless in my class
  return $self;
 }
 
-sub is_compatible_with_protocol { return 1; }
-
 sub send
 {
  my ($self,$ctx,$tosend)=@_;
@@ -116,13 +108,10 @@ sub receive
 sub _got_ok
 {
  my ($self,$count)=@_;
-
  my $m="200 OK\r\n.\r\n";
- 
  print STDOUT "<<<<<<<<<<<<<<<<<< (Net::DRI::Transport::Dummy) (count=$count)\n";
  print STDOUT $m;
  print STDOUT "<<<<<<<<<<<<<<<<<<\n\n";
-
  return Net::DRI::Data::Raw->new_from_string($m);
 }
 
