@@ -1,6 +1,6 @@
 ## Domain Registry Interface, SOAP Transport
 ##
-## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,23 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::Transport::HTTP::SOAPLite;
 
-use base qw(Net::DRI::Transport);
 use strict;
+use warnings;
+
+use base qw(Net::DRI::Transport);
 
 use Net::DRI::Exception;
 use Net::DRI::Data::Raw;
 use Net::DRI::Util;
 use SOAP::Lite;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -55,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008-2011 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,19 +65,29 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
+
 sub new
 {
- my $class=shift;
- my $ctx=shift;
+ my ($class,$ctx,$rp)=@_;
+ my %opts=%$rp;
  my $po=$ctx->{protocol};
 
- my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
+ my %t=(message_factory => $po->factories()->{message});
+ if (exists($opts{protocol_connection}) && $opts{protocol_connection})
+ {
+  $t{protocol_connection}=$opts{protocol_connection};
+  $t{protocol_connection}->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$t{protocol_connection},$@);
+  if ($t{protocol_connection}->can('transport_default'))
+  {
+   %opts=($t{protocol_connection}->transport_default('soaplite'),%opts);
+  }
+ }
+
  my $self=$class->SUPER::new($ctx,\%opts); ## We are now officially a Net::DRI::Transport instance
  $self->is_sync(1);
  $self->name('soaplite');
- $self->version($VERSION);
+ $self->version('0.1');
 
- my %t=(message_factory => $po->factories()->{message});
  $t{has_login}=(exists($opts{has_login}) && defined($opts{has_login}))? $opts{has_login} : 0;
  $t{has_logout}=(exists($opts{has_logout}) && defined($opts{has_logout}))? $opts{has_logout} : 0;
  $self->has_state($t{has_login});
@@ -91,13 +98,7 @@ sub new
   $t{$p}=$opts{$p};
  }
 
- if ($t{has_login})
- {
-  $t{session_data}={};
- } else
- {
-  $t{session_data}={ id => $t{client_login}, pass => $t{client_password} };
- }
+ $t{session_data}=$t{has_login}? {} : { id => $t{client_login}, pass => $t{client_password} };
 
  foreach my $p (qw/uri proxy_uri/)
  {
@@ -110,7 +111,6 @@ sub new
  if ($t{has_login} || $t{has_logout})
  {
   Net::DRI::Exception::usererr_insufficient_parameters('protocol_connection must be provided') unless (defined($pc));
-  $pc->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$pc,$@);
  }
  if ($t{has_login})
  {
@@ -128,7 +128,6 @@ sub new
  }
 
  $self->{transport}=\%t;
- bless($self,$class);
 
  if ($self->has_state())
  {
@@ -151,18 +150,12 @@ sub new
 sub soap { my ($self,$v)=@_; $self->{transport}->{soap}=$v if @_==2; return $self->{transport}->{soap}; }
 sub session_data { my ($self,$v)=@_; $self->{transport}->{session_data}=$v if @_==2; return $self->{transport}->{session_data}; }
 
-sub soap_fault
-{
- my($soap,$res)=@_; 
- my $msg=ref($res)? $res->faultstring() : $soap->transport()->status();
- Net::DRI::Exception->die(1,'transport/http/soaplite',7,'SOAP fault: '.$msg);
-}
-
 sub init
 {
  my ($self)=@_;
  return if defined($self->soap());
- my $soap=SOAP::Lite->new()->on_fault(\&soap_fault)->uri($self->{transport}->{uri})->proxy($self->{transport}->{proxy_uri});
+ my $soap=SOAP::Lite->new()->uri($self->{transport}->{uri})->proxy($self->{transport}->{proxy_uri});
+ $soap->transport()->agent(sprintf('Net::DRI/%s ',$Net::DRI::VERSION).$soap->transport()->agent());
  $self->soap($soap);
 }
 
@@ -177,13 +170,9 @@ sub send_login
  }
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$self->generate_trid();
+ my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
  my $login=$pc->login($t->{message_factory},$t->{client_login},$t->{client_password},$cltrid);
- my $lm=$login->method();
- my $res=$self->soap()->$lm(@{$login->params()});
- ## TODO logging
- Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send login message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
- ## TODO logging
+ my $res=$self->_send_receive({otype=>'session',oaction=>'login',trid=>$cltrid,phase=>'opening'},$login);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res->result()]));
  my $rc=$pc->parse_login($msg);
@@ -194,18 +183,14 @@ sub send_login
 
 sub send_logout
 {
- my ($self,$ctx)=@_;
+ my ($self)=@_;
  my $t=$self->{transport};
  return unless $t->{has_logout};
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$self->generate_trid();
+ my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
  my $logout=$pc->logout($t->{message_factory},$cltrid,$t->{session_data});
- my $lm=$logout->method();
- my $res=$self->soap()->$lm(@{$logout->params()});
- ## TODO logging
- Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send logout message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
- ## TODO logging
+ my $res=$self->_send_receive({otype=>'session',oaction=>'logout',trid=>$cltrid,phase=>'closing'},$logout);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res->result()]));
  my $rc=$pc->parse_logout($msg);
@@ -214,6 +199,27 @@ sub send_logout
  $self->session_data({});
 }
 
+sub _send_receive
+{
+ my ($self,$ctx,$msg)=@_;
+ my $soap=$self->soap();
+ my $err;
+ my $res=$soap->on_fault(sub { (undef,$err)=@_; return; })->call($msg->method(),@{$msg->params()});
+ if (my $httpres=$soap->transport()->http_response())
+ {
+  $self->log_output('notice','transport',$ctx,{direction=>'out',message=>$httpres->request()});
+  $self->log_output('notice','transport',$ctx,{direction=>'in', message=>$httpres});
+ } else
+ {
+  $self->log_output('error','transport',$ctx,{direction=>'out',message=>'No response for message '.$soap->serializer()->envelope(method => $msg->method(), @{$msg->params()})});
+ }
+ return $res if defined $res && ref $res && ! $res->fault() && ! defined $err;
+
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP fault: '.$err->faultcode().' '.$err->faultstring()) if defined $err && ref $err;
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP transport error: '.$soap->transport()->status()) unless $soap->transport()->is_success();
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP deserialization error: '.$err);
+}
+
 sub open_connection
 {
  my ($self,$ctx)=@_;
@@ -226,22 +232,22 @@ sub open_connection
 
 sub close_connection
 {
- my ($self,$ctx)=@_;
- $self->send_logout($ctx);
+ my ($self)=@_;
+ $self->send_logout();
  $self->soap(undef);
  $self->current_state(0);
 }
 
 sub end
 {
- my ($self,$ctx)=@_;
+ my ($self)=@_;
  if ($self->has_state() && $self->current_state())
  {
   eval
   {
    local $SIG{ALRM}=sub { die 'timeout' };
    alarm(10);
-   $self->close_connection($ctx);
+   $self->close_connection();
   };
   alarm(0); ## since close_connection may die, this must be outside of eval to be executed in all cases
  }
@@ -257,11 +263,10 @@ sub send
 
 sub _soap_send
 {
- my ($self,$count,$tosend)=@_;
+ my ($self,$count,$tosend,$ctx)=@_;
  my $t=$self->{transport};
  $tosend->add_session($self->session_data());
- my $m=$tosend->method();
- my $res=$self->soap()->$m(@{$tosend->params()});
+ my $res=$self->_send_receive($ctx,$tosend);
  $t->{last_reply}=$res;
  return 1; ## very important
 }
@@ -277,9 +282,8 @@ sub _soap_receive
  my ($self,$count)=@_;
  my $t=$self->{transport};
  my $r=$t->{last_reply};
- Net::DRI::Exception->die(1,'transport/soapwsdl',7,'SOAP fault: '.$r->faultcode().' '.$r->faultstring()) if ($r->fault());
  $t->{last_reply}=undef;
- return Net::DRI::Data::Raw->new(1,[$r->result()]);
+ return Net::DRI::Data::Raw->new(6,[$r->result()]);
 }
 
 ####################################################################################################
